@@ -1,3 +1,4 @@
+import json
 import logging
 import time
 from pathlib import Path
@@ -541,6 +542,130 @@ class Jobs:
             extra_technology_version,
         )
 
+    def create_or_upgrade(
+        self,
+        job_name: str,
+        project_id: str,
+        file: str = None,
+        description: str = "",
+        category: str = "Processing",
+        technology: str = "python",
+        technology_catalog: str = "Saagie",
+        runtime_version: str = "3.8",
+        command_line: str = "python {file} arg1 arg2",
+        release_note: str = "",
+        extra_technology: str = "",
+        extra_technology_version: str = "",
+        is_scheduled: bool = False,
+        cron_scheduling: str = None,
+        schedule_timezone: str = "UTC",
+        resources: Dict = None,
+        emails: List = None,
+        status_list: List = None,
+    ) -> Dict:
+        """Create or upgrade a job
+
+        Parameters
+        ----------
+        job_name : str
+            Name of your job
+        project_id : str
+            UUID of your project
+        file: str (optional)
+            Path to your file
+        description: str (optional)
+            Description of your job
+        category: str (optional)
+            Category of your job
+        technology: str (optional)
+            Technology of your job
+        technology_catalog: str (optional)
+            Technology catalog of your job
+        runtime_version: str (optional)
+            Runtime version
+        command_line: str (optional)
+            Command line
+        release_note: str (optional)
+            Release note
+        extra_technology: str (optional)
+            Extra technology when needed (spark jobs). If not needed, leave to
+            empty string or the request will not work
+        extra_technology_version: str (optional)
+            Version of the extra technology. Leave to empty string when not
+            needed
+        is_scheduled: bool (optional)
+            True if the job is scheduled, False to deactivate scheduling
+        cron_scheduling: str (optional)
+            Cron scheduling
+        schedule_timezone: str (optional)
+            Schedule timezone
+        resources: dict (optional)
+            Resources
+        emails: list (optional)
+            Emails
+        status_list: list (optional)
+            Status list
+
+        Returns
+        -------
+        dict
+            Either the same dict as create_job, or the one returned by
+            concatenation of upgrade_job and edit_job
+        """
+
+        job_list = self.saagie_api.jobs.list_for_project_minimal(project_id)["jobs"]
+        job_names = [job["name"] for job in job_list]
+
+        if job_name in job_names:
+            job_id = [job["id"] for job in job_list if job["name"] == job_name][0]
+
+            responses = {}
+
+            responses["addJobVersion"] = self.upgrade(
+                job_id=job_id,
+                file=file,
+                use_previous_artifact=True,
+                runtime_version=runtime_version,
+                command_line=command_line,
+                release_note=release_note,
+                extra_technology=extra_technology,
+                extra_technology_version=extra_technology_version,
+            )["data"]["addJobVersion"]
+
+            responses["editJob"] = self.edit(
+                job_id=job_id,
+                job_name=job_name,
+                description=description,
+                is_scheduled=is_scheduled,
+                cron_scheduling=cron_scheduling,
+                schedule_timezone=schedule_timezone,
+                resources=resources,
+                emails=emails,
+                status_list=status_list,
+            )["editJob"]
+
+            return responses
+        else:
+            return self.create(
+                job_name=job_name,
+                project_id=project_id,
+                file=file,
+                description=description,
+                category=category,
+                technology=technology,
+                technology_catalog=technology_catalog,
+                runtime_version=runtime_version,
+                command_line=command_line,
+                release_note=release_note,
+                extra_technology=extra_technology,
+                extra_technology_version=extra_technology_version,
+                cron_scheduling=cron_scheduling,
+                schedule_timezone=schedule_timezone,
+                resources=resources,
+                emails=emails,
+                status_list=status_list,
+            )
+
     def delete(self, job_id: str) -> Dict:
         """Delete a given job
 
@@ -768,3 +893,90 @@ class Jobs:
             logging.warning("❌ Job [%s] has not been successfully exported", job_id)
             write_error(error_folder, "jobs", job_id)
         return result
+
+    def import_from_json(
+        self,
+        json_file: str,
+        project_id: str,
+        path_to_package: str = None,
+    ) -> bool:
+        """Import a job from JSON format
+
+        Parameters
+        ----------
+        json_file : str
+            Path to the JSON file that contains job information
+        project_id : str
+            Project ID to import the job
+        path_to_package : str, optional
+            Path to the package of the job to import
+        Returns
+        -------
+        bool
+            True if job is imported False otherwise
+        """
+        result = True
+
+        try:
+            with open(json_file, "r") as file:
+                job_info = json.load(file)
+        except Exception as e:
+            logging.warning("Cannot open the JSON file %s", json_file)
+            logging.error("Something went wrong %s", e)
+            return False
+
+        try:
+            job_name = job_info["name"]
+            job_description = job_info["description"]
+            job_category = job_info["category"]
+            job_technology_name = job_info["technology"]["name"]
+            job_technology_catalog = job_info["technology"]["technology_catalog"]
+
+            for version in job_info["versions"]:
+                if version["isCurrent"]:
+                    job_runtime_version = version["runtimeVersion"]
+                    job_command_line = version["commandLine"]
+                    job_release_note = version["releaseNote"]
+                    job_extra_technology_name = ""
+                    job_extra_technology_version = ""
+
+                    if version["extraTechnology"] is not None:
+                        job_extra_technology_name = version["extraTechnology"]["language"]
+                        job_extra_technology_version = version["extraTechnology"]["version"]
+
+            job_cron_scheduling = job_info["cronScheduling"]
+            job_schedule_timezone = job_info["scheduleTimezone"]
+            job_resources = job_info["resources"]
+            job_emails = ""
+            job_status_list = ""
+
+            if job_info["alerting"] is not None:
+                job_emails = job_info["alerting"]["emails"]
+                job_status_list = job_info["alerting"]["statusList"]
+
+            self.create(
+                job_name,
+                project_id,
+                path_to_package,
+                job_description,
+                job_category,
+                job_technology_name,
+                job_technology_catalog,
+                job_runtime_version,
+                job_command_line,
+                job_release_note,
+                job_extra_technology_name,
+                job_extra_technology_version,
+                job_cron_scheduling,
+                job_schedule_timezone,
+                job_resources,
+                job_emails,
+                job_status_list,
+            )
+            logging.info("✅ Job [%s] successfully imported", job_name)
+        except Exception as e:
+            result = False
+            logging.warning("❌ Job [%s] has not been successfully imported", job_name)
+            logging.error("Something went wrong %s", e)
+
+        return result
