@@ -1,3 +1,4 @@
+import json
 import logging
 import time
 from typing import Dict, List, Optional
@@ -401,6 +402,101 @@ class Pipelines:
         logging.info("✅ Pipeline [%s] successfully edited", name)
         return result
 
+    def create_or_upgrade(
+        self,
+        name: str,
+        project_id: str,
+        graph_pipeline: GraphPipeline,
+        description: str = "",
+        release_note: str = "",
+        emails: List[str] = None,
+        status_list: List[str] = None,
+        is_scheduled: bool = None,
+        cron_scheduling: str = None,
+        schedule_timezone: str = "UTC",
+    ) -> Dict:
+        """Create or upgrade a pipeline in a given project
+
+        Parameters
+        ----------
+        name : str
+            Pipeline name
+        project_id : str
+            UUID of your project (see README on how to find it)
+        graph_pipeline : GraphPipeline
+            Example: If you want to create a simple pipeline with 2 jobs that started by job_node_1,
+            you can use the following example
+                job_node1 = JobNode(job_id_1)
+                job_node2 = JobNode(job_id_2)
+                job_node1.add_next_node(job_node2) # Indicates that the job_node_1 is followed by job_node_2
+                graph_pipeline = GraphPipeline()
+                graph_pipeline.add_root_node(job_node1) # Indicates the pipeline will start with job_node1
+        description : str, optional
+            Description of the pipeline
+            if not filled, defaults to current value, else it will change the description of the pipeline
+        release_note: str, optional
+            Release note of the pipeline
+        emails: List[String], optional
+            Emails to receive alerts for the job, each item should be a valid email,
+            If you want to remove alerting, please set emails to [] or list()
+            if not filled, defaults to current value
+        status_list: List[String], optional
+            Receive an email when the job status change to a specific status
+            Each item of the list should be one of these following values: "REQUESTED", "QUEUED",
+            "RUNNING", "FAILED", "KILLED", "KILLING", "SUCCEEDED", "UNKNOWN", "AWAITING", "SKIPPED"
+        is_scheduled : bool, optional
+            True to activate the pipeline scheduling
+        cron_scheduling : str, optional
+            Scheduling CRON format
+            When is_scheduled is set to True, it will be mandatory to fill this value
+            if not filled, defaults to current value
+            Example: "0 0 * * *" (for every day At 00:00)
+        schedule_timezone : str, optional
+            Timezone of the scheduling
+            Example: "UTC", "Pacific/Pago_Pago"
+
+        Returns
+        -------
+        dict
+            Dict of pipeline information
+        """
+        pipeline_list = self.saagie_api.pipelines.list_for_project_minimal(project_id)["project"]["pipelines"]
+        pipeline_names = [pipeline["name"] for pipeline in pipeline_list]
+
+        if name in pipeline_names:
+            pipeline_id = [pipeline["id"] for pipeline in pipeline_list if pipeline["name"] == name][0]
+
+            responses = {}
+            responses["editPipeline"] = self.edit(
+                pipeline_id,
+                name,
+                description,
+                emails,
+                status_list,
+                is_scheduled,
+                cron_scheduling,
+                schedule_timezone,
+            )["editPipeline"]
+
+            responses["addGraphPipelineVersion"] = self.upgrade(pipeline_id, graph_pipeline, release_note)[
+                "addGraphPipelineVersion"
+            ]
+
+            return responses
+
+        else:
+            return self.create_graph(
+                name,
+                project_id,
+                graph_pipeline,
+                description,
+                release_note,
+                emails,
+                status_list,
+                cron_scheduling,
+                schedule_timezone,
+            )
+
     def run(self, pipeline_id: str) -> Dict:
         """Run a given pipeline
         NB : You can only run pipeline if you have at least the editor role on
@@ -550,3 +646,106 @@ class Pipelines:
             write_error(error_folder, "pipelines", pipeline_id)
             result = False
         return result
+
+    def import_from_json(self, json_file: str, project_id: str) -> bool:
+        """Import pipeline from JSON format
+        Parameters
+        ----------
+        json_file : str
+            IPath to the JSON file that contains pipeline information
+        project_id : str
+            Project ID
+        Returns
+        -------
+        bool
+            True if pipelines are imported False otherwise
+        """
+        result = True
+
+        try:
+            with open(json_file, "r") as file:
+                pipeline_info = json.load(file)
+        except Exception as e:
+            logging.warning("Cannot open the JSON file %s", json_file)
+            logging.error("Something went wrong %s", e)
+            return False
+
+        try:
+            pipeline_name = pipeline_info["name"]
+            pipeline_description = pipeline_info["description"]
+            emails = pipeline_info["alerting"]["emails"]
+            status_list = pipeline_info["alerting"]["statusList"]
+            cron_scheduling = pipeline_info["cronScheduling"]
+            schedule_timezone = pipeline_info["scheduleTimezone"]
+
+            all_jobs_for_target_project = self.saagie_api.jobs.list_for_project_minimal(project_id)["jobs"]
+
+            for version in pipeline_info["versions"]:
+                if version["isCurrent"]:
+                    release_note = version["releaseNote"]
+                    jobs_not_found = []
+                    jobs_found = []
+                    for job_node in version["graph"]["jobNodes"]:
+                        job_found_in_target_project = False
+                        for job in all_jobs_for_target_project:
+                            if job["name"] == job_node["job"]["name"]:
+                                job_found_in_target_project = True
+                                node_dict = {
+                                    "id": job_node["id"],
+                                    "job": {"id": job["id"]},
+                                    "nextNodes": job_node["nextNodes"],
+                                }
+                                jobs_found.append(node_dict)
+                                break
+                        if not job_found_in_target_project:
+                            jobs_not_found.append(job_node["job"]["name"])
+
+                    conditions_found = []
+                    for condition_node in version["graph"]["conditionNodes"]:
+                        condition_dict = {
+                            "id": condition_node["id"],
+                            "nextNodesSuccess": condition_node["nextNodesSuccess"],
+                            "nextNodesFailure": condition_node["nextNodesFailure"],
+                        }
+                        conditions_found.append(condition_dict)
+
+                    if len(jobs_not_found) > 0:
+                        result = False
+                        not_found = ""
+                        for job in jobs_not_found:
+                            not_found += job + ", "
+                        logging.error(
+                            "❌ Import aborted, in target project (id : %s), the following jobs were not found: %s",
+                            project_id,
+                            not_found,
+                        )
+                    else:
+                        graph_pipeline = GraphPipeline()
+                        graph_pipeline.list_job_nodes = jobs_found
+                        graph_pipeline.list_conditions_nodes = conditions_found
+                        res = self.saagie_api.pipelines.create_graph(
+                            pipeline_name,
+                            project_id,
+                            graph_pipeline,
+                            pipeline_description,
+                            release_note,
+                            emails,
+                            status_list,
+                            cron_scheduling,
+                            schedule_timezone,
+                        )
+                        if res["createGraphPipeline"] is not None:
+                            result = True
+                        else:
+                            result = False
+                            logging.error("❌ Something went wrong %s", res)
+        except Exception as e:
+            result = False
+            logging.error("❌ Something went wrong %s", e)
+
+        if result:
+            logging.info("✅ Pipeline [%s] has been successfully imported", pipeline_name)
+        else:
+            logging.warning("❌ Pipeline [%s] has not been successfully imported", pipeline_name)
+
+        return result
